pub fn load_cached_go_module(
store: &mut Store,
module_id: &str,
cache: &GoStdlibCache,
)Expand description
Load a Go module and its transitive deps from cache, recursively.
pub fn load_cached_go_module(
store: &mut Store,
module_id: &str,
cache: &GoStdlibCache,
)Load a Go module and its transitive deps from cache, recursively.