pub enum CachedType {
Constructor {
id: String,
params: Vec<CachedType>,
underlying_ty: Option<Box<CachedType>>,
},
Function {
params: Vec<CachedType>,
param_mutability: Vec<bool>,
bounds: Vec<CachedBound>,
return_type: Box<CachedType>,
},
Forall {
vars: Vec<String>,
body: Box<CachedType>,
},
Parameter(String),
Tuple(Vec<CachedType>),
Never,
}Expand description
Serializable type representation. All type variables are resolved to either concrete types or Parameters.
Variants
Constructor
Function
Forall
Parameter(String)
Tuple(Vec<CachedType>)
Never
Implementations
Sourceimpl CachedType
impl CachedType
Sourcepub fn from_type_with_vars(
ty: &Type,
var_names: &mut HashMap<i32, String>,
) -> Self
pub fn from_type_with_vars( ty: &Type, var_names: &mut HashMap<i32, String>, ) -> Self
Convert a Type to CachedType by resolving all type variables. Uses a var_names map to ensure distinct type variables get distinct parameter names, even if they have the same hint.
pub fn from_type(ty: &Type) -> Self
pub fn to_type(&self) -> Type