pub struct Scopes { /* private fields */ }Implementations
Sourceimpl Scopes
impl Scopes
pub fn new() -> Self
pub fn current(&self) -> &Scope
pub fn current_mut(&mut self) -> &mut Scope
pub fn push(&mut self)
pub fn pop(&mut self)
pub fn reset(&mut self)
Sourcepub fn lookup_value(&self, name: &str) -> Option<&Type>
pub fn lookup_value(&self, name: &str) -> Option<&Type>
Look up a value by walking the scope stack from top to bottom.
Sourcepub fn lookup_mutable(&self, name: &str) -> bool
pub fn lookup_mutable(&self, name: &str) -> bool
Check if a variable is marked mutable in any enclosing scope.
Sourcepub fn lookup_const(&self, name: &str) -> bool
pub fn lookup_const(&self, name: &str) -> bool
Whether name is a block-local const in any enclosing scope.
Sourcepub fn lookup_binding_id(&self, name: &str) -> Option<BindingId>
pub fn lookup_binding_id(&self, name: &str) -> Option<BindingId>
Look up a binding ID by walking the scope stack from top to bottom.
Sourcepub fn lookup_type_param(&self, name: &str) -> Option<usize>
pub fn lookup_type_param(&self, name: &str) -> Option<usize>
Look up a type parameter by walking the scope stack from top to bottom.
Sourcepub fn lookup_fn_return_type(&self) -> Option<&Type>
pub fn lookup_fn_return_type(&self) -> Option<&Type>
Look up the enclosing function’s return type.
Sourcepub fn lookup_try_block_context(&self) -> Option<&TryBlockContext>
pub fn lookup_try_block_context(&self) -> Option<&TryBlockContext>
Look up the enclosing try block context, stopping at function boundaries.
Sourcepub fn lookup_recover_block_context(&self) -> Option<&RecoverBlockContext>
pub fn lookup_recover_block_context(&self) -> Option<&RecoverBlockContext>
Look up the enclosing recover block context, stopping at function boundaries.
pub fn collect_all_value_names(&self) -> Vec<String>
pub fn collect_all_trait_bounds(&self) -> HashMap<Symbol, Vec<Type>>
pub fn for_each_bound_on_param<F: FnMut(&Type)>( &self, param_name: &str, visit: F, )
pub fn increment_loop_depth(&self)
pub fn decrement_loop_depth(&self)
pub fn is_inside_loop(&self) -> bool
pub fn set_loop_break_type(&mut self, ty: Type)
pub fn clear_loop_break_type(&mut self)
pub fn loop_break_type(&self) -> Option<&Type>
pub fn increment_defer_block_depth(&self)
pub fn decrement_defer_block_depth(&self)
pub fn is_inside_defer_block(&self) -> bool
pub fn defer_block_loop_depth(&self) -> usize
pub fn increment_negation_depth(&self)
pub fn decrement_negation_depth(&self)
pub fn is_inside_negation(&self) -> bool
pub fn reset_loop_depth(&self) -> usize
pub fn restore_loop_depth(&self, depth: usize)
pub fn set_value_context(&self) -> UseContext
pub fn set_statement_context(&self) -> UseContext
pub fn restore_use_context(&self, ctx: UseContext)
pub fn is_value_context(&self) -> bool
pub fn set_callee_context(&self) -> UseContext
pub fn is_callee_context(&self) -> bool
pub fn set_assignment_target_context(&self) -> UseContext
pub fn is_assignment_target_context(&self) -> bool
pub fn is_in_match_arm(&self) -> bool
pub fn set_in_match_arm(&self, value: bool) -> bool
pub fn push_loop_needs_label(&self)
pub fn pop_loop_needs_label(&self) -> bool
pub fn mark_current_loop_needs_label(&self)
pub fn is_in_subexpression(&self) -> bool
pub fn set_in_subexpression(&self, value: bool) -> bool
pub fn is_dot_access_base(&self) -> bool
pub fn set_dot_access_base(&self, value: bool) -> bool
pub fn increment_type_param_depth(&self)
pub fn decrement_type_param_depth(&self)
pub fn is_inside_type_param(&self) -> bool
pub fn set_impl_receiver_type(&mut self, ty: Option<Type>)
pub fn impl_receiver_type(&self) -> Option<&Type>