pub fn register_cached_module(
store: &mut Store,
module_id: &str,
cached: ModuleInterface,
)Expand description
Register a cached module in the store. This loads the cached definitions and source files without running inference.
pub fn register_cached_module(
store: &mut Store,
module_id: &str,
cached: ModuleInterface,
)Register a cached module in the store. This loads the cached definitions and source files without running inference.