Module types

Module types 

Structs

CachedAttribute
CachedBound
CachedEnumField
CachedEnumVariant
CachedGeneric
CachedInterface
CachedSpan
Span stored as file index + byte offsets. file_index refers to position in ModuleInterface.files array (sorted by filename). When loading from cache, file indices are remapped to newly assigned file IDs.
CachedStructField
CachedValueEnumVariant

Enums

CachedDefinition
Serializable version of Definition with all type variables resolved.
CachedLiteral
CachedType
Serializable type representation. All type variables are resolved to either concrete types or Parameters.
CachedVariantFields