Structs
- File
Content - Source content plus a cwd-relative display path for diagnostics.
display_pathmatchesnamefor loaders that have no notion of cwd (test/overlay loaders); the CLI’s filesystem loader sets it to the path relative to the process cwd.