Module loader

Module loader 

Structs

FileContent
Source content plus a cwd-relative display path for diagnostics. display_path matches name for loaders that have no notion of cwd (test/overlay loaders); the CLI’s filesystem loader sets it to the path relative to the process cwd.

Traits

Loader

Type Aliases

Files